# Welcome to enzax's documentation!

Enzax is a library of kinetic models of enzyme-catalysed reaction networks. It supports automatic differentiation using [JAX](https://jax.readthedocs.io/en/latest/), allowing you to find your models' gradients, as required for e.g. Hamiltonian Monte Carlo or neural network models.

The [getting started](getting_started.md) page explains how to install enzax and use it to find and differentiate the steady states of an example model.

If you would like to contribute to enzax, the [contributing](contributing.md)
page has some useful information.

See the [accessibility](accessibility.md) page for how we try to make enzax as
useable as possible for everyone.
